#
# spec file for package google-glog
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           google-glog
Version:        0.3.5
Release:        1.25
Summary:        Logging library for C++
License:        BSD-3-Clause
Group:          System/Libraries
Url:            https://github.com/google/glog
Source:         glog-%{version}.zip
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  unzip
BuildRequires:  cmake
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The glog library implements application-level logging.
This library provides logging APIs based on C++-style
streams and various helper macros.

%package -n libglog0
Summary:        Logging library for C++
Group:          System/Libraries

%description -n libglog0
The glog library implements application-level logging.
This library provides logging APIs based on C++-style
streams and various helper macros.

%package -n glog-devel
Summary:        Header files for libglog0
Group:          Development/Libraries/C and C++
Requires:       libglog0 = %{version}

%description -n glog-devel
The glog library implements application-level logging.
This library provides logging APIs based on C++-style
streams and various helper macros.

This package provides development files for libglog0.

%prep
%setup -q -n glog-%{version}

%build
%configure
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
rm -rf %{buildroot}%{_libdir}/*.{a,la}
rm -rf %{buildroot}%{_datadir}/doc/glog-*

%post -n libglog0 -p /sbin/ldconfig
%postun -n libglog0 -p /sbin/ldconfig

%files -n libglog0
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libglog.so.0
%{_libdir}/libglog.so.0.0.0

%files -n glog-devel
%defattr(-,root,root)
%doc COPYING AUTHORS ChangeLog README
%{_includedir}/glog/
%{_libdir}/libglog.so
%{_libdir}/pkgconfig/libglog.pc

%changelog
* Sun Jun  4 2017 plinnell@opensuse.org
- Update to 0.3.5
  - CHECK_NOTNULL works with smart pointers when compiled in C++11
  - Add __declspec(noreturn) on Win
  - DCHECK_ALWAYS_ON to make D* enabled under NDEBUG
  - MinGW: avoid the error "conflicting declaration 'typedef DWORD pthread_t'" etc.
  - NULL sinks_ after deletion to prevent dangling pointer
  - Symbolize: Calculate a module's zero VA using program headers
  - Allow permission line in /proc/self/map to be "rwx"
  - Add support for PowerPC
  - Use namespace GFLAGS_NAMESPACE instead namespace gflags. #62
  - Win: use _fdopen instead of fdopen. Fix #73
  - Win: FAILED macro can't be used with HANDLE. Fix #79
  - Avoid calling new/malloc in signalhandler to fix #78
  - Reset SIGABRT action only if FailureSignalHandler is installed
  - Fix missing public include directory
  - Fix double-free in unit test on Windows
  - Add logfile_mode to control logfile permissions to fix #23
  - Fix mocklog unused arguments
  - Fix redefinition of _XOPEN_SOURCE
  - Don't call RAW_VLOG with locking vmodule_lock to fix #29
  - Add CMake support. closes #4
  - Fix #8 AddLogSink memory leak
  - Add #ifndefs to avoid collision with other google opensource projects
  - LOG_STRING: use std::vector and std::string
  - Adds color output support for tmux terminals
  - Fix x64/Debug build on MSVS
- Changes from 0.3.4
  - repository moved from code.google.com/p/google-glog to github.com/google/glog
  - fixes for latest MSVS
  - add libc++ support
  - fix build issue in demangle.cc
  - add callback for OpenObjectFileContainingPcAndGetStartAddress
  - add StrError and replace posix_strerror_r call
  - fix VC build by adding GOOGLE_GLOG_DLL_DECL
  - style fix for C++11
  - reduce dynamic allocation from 3 to 1 per log message
  - attempt to improve mingw-w64 support
  - support unordered_(map|set) by stl_logging
* Wed Mar 16 2016 mpluskal@suse.com
- Install documentation in default location with correct
  permissions
- Use macro for configure
- Cleanup spec file with spec-cleaner
* Mon Feb 29 2016 qzhao@suse.com
- Make sure source code's COPYING file install by default.
* Sat Jun 29 2013 i@marguerite.su
- update version 0.3.3
  * Add --disable-rtti option for configure.
  * Visual Studio build and test fix.
  * QNX build fix (thanks vanuan).
  * Reduce warnings.
  * Fixed LOG_SYSRESULT (thanks ukai).
  * FreeBSD build fix (thanks yyanagisawa).
  * Clang build fix.
  * Now users can re-initialize glog after ShutdownGoogleLogging.
  * Color output support by GLOG_colorlogtostderr (thanks alexs).
  * Now glog's ABI around flags are compatible with gflags.
  * Document mentions how to modify flags from user programs.
* Thu Oct 11 2012 i@marguerite.su
- initial version 0.3.2
  * Clang support.
  * Demangler and stacktrace improvement for newer GCCs.
  * Now fork(2) doesn't mess up log files.
  * Make valgrind happier.
  * Reduce warnings for more -W options.
  * Provide a workaround for ERROR defined by windows.h.
